.. currentmodule:: pdcast

.. _boolean_types:

Boolean
=======

Generic
-------

.. _boolean_type:

.. autoclass:: BooleanType

Numpy
-----

.. _numpy_boolean_type:

.. autoclass:: NumpyBooleanType

Pandas
------

.. _pandas_boolean_type:

.. autoclass:: PandasBooleanType

Python
------

.. _python_boolean_type:

.. autoclass:: PythonBooleanType
